<!--巡检计划-->
<template>
  <div class="bbsl-common-page">
    <template v-if="componentName === 'table'">
      <div class="bbsl-table-search">
        <el-form v-model="queryParams" label-width="auto">
          <el-row :gutter="10">
            <el-col :span="5">
              <el-form-item label="巡检计划名称">
                <el-input :clearable="true" placeholder="请输入巡查计划名称" v-model="queryParams['plan_Name_']" />
              </el-form-item>
            </el-col>
            <el-col :span="5">
              <el-form-item label="巡检开始时间">
                <el-date-picker clearable type="date" value-format="yyyy-MM-dd" style="width:100%" placeholder="请选择巡查时间"
                  v-model="queryParams['plan_Start_Date_']"></el-date-picker>
              </el-form-item>
            </el-col>
            <el-col :span="5">
              <el-form-item label="巡检结束时间" prop="startTime">
                <el-date-picker clearable type="date" value-format="yyyy-MM-dd" style="width:100%" placeholder="请选择巡查时间"
                  v-model="queryParams['plan_End_Date_']"></el-date-picker>
              </el-form-item>
            </el-col>
            <el-col :span="5">
              <el-form-item label="巡检类型">
                <el-select placeholder="请选择巡检类型" v-model="queryParams['plan_Type_']" clearable>
                  <el-option v-for="item in inspectionTypeOpt" :key="item.value" :label="item.name"
                    :value="item.value" />
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="4">
              <el-button type="primary" icon="el-icon-search" @click="handleSearch">
                搜索
              </el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">
                重置
              </el-button>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <div class="bbsl-table-content" ref="contentPanel">
        <div class="bbsl-btn-content" ref="btnPanel">
          <el-button icon="el-icon-plus" type="primary" @click="openPage('isShowAddModify')">
            新增
          </el-button>
          <el-button icon="el-icon-delete" type="danger" plain class="btn btn-delete"
            :disabled="!multipleSelection.length" @click="handleDelete()">
            删除
          </el-button>
        </div>
        <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
          :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
          :header-cell-style="{ 'text-align': 'center' }" @selection-change="handleSelectionChange"
          @sort-change="sortChange" row-key="id" @row-dblclick="row => openPage('isShowAddModify', row)">
          <el-table-column reserve-selection type="selection" width="55" align="center"></el-table-column>
          <el-table-column type="index" width="70" label="序号" align="center">
          </el-table-column>
          <el-table-column prop="planName" show-overflow-tooltip align="center" label="巡检计划名称" min-width="150" />
          <el-table-column prop="planContent" show-overflow-tooltip align="center" label="巡检内容" min-width="150" />

          <el-table-column prop="planType" show-overflow-tooltip align="center" label="巡检类型" min-width="100"
            :formatter="({ planType }) => dictionaryEscape(inspectionTypeOpt, planType + '')" />
          <el-table-column prop="planStartDate" show-overflow-tooltip min-width="100" align="center" label="巡检开始时间" />
          <el-table-column prop="planEndDate" show-overflow-tooltip min-width="100" align="center" label="巡检结束时间" />
          <el-table-column show-overflow-tooltip min-width="100" align="center" label="分发状态">
            <template v-slot="{ row }">
              <el-tag v-if="row.planStatus < 1" type="info">未分发</el-tag>
              <el-tag v-else type="success">已分发</el-tag>
            </template>
          </el-table-column>
          <el-table-column show-overflow-tooltip min-width="120" align="center" fixed="right" label="操作">
            <template v-slot="{ row }">
              <el-link v-if="row.planStatus < 1" type="primary" :underline="false" style="margin-right: 15px;"
                @click="planDistribute(row)">
                分发
              </el-link>
              <el-link v-if="row.planStatus === 1" type="danger" :underline="false" @click="handleRetract(row)">
                撤回
              </el-link>
              <el-link v-if="row.planStatus < 1" type="danger" :underline="false" @click="handleDelete(row)">
                删除
              </el-link>
            </template>
          </el-table-column>
        </el-table>
        <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
          @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParams.page"
          :page-sizes="[20, 30, 40, 50]" :page-size="queryParams.pageSize"
          layout="total, sizes, prev, pager, next, jumper" :total="queryParams.total"></el-pagination>
      </div>
    </template>

    <!--  新增修改页面  -->
    <AddModifyPage v-if="componentName === 'isShowAddModify'" :inspectionTypeOpt="inspectionTypeOpt" :row-info="rowInfo"
      @closePage="closePage" />

    <DetailModifyPage v-if="componentName === 'isShowDetailModify'" :inspectionTypeOpt="inspectionTypeOpt"
      :row-info="rowInfo" @closePage="closePage" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import { removePlanById, tableData, planDistribute, planRetract } from '@/api/device/resourceInspection/resourceInspection'
import dictUtils from '@/components/dict/DictSelectUtils'
import { dictionaryEscape } from '@/utils/dictionary'
import AddModifyPage from './components/AddModifyPage/index.vue'
import DetailModifyPage from './components/DetailModifyPage/index.vue'

export default {
  name: 'EquipmentInspectionPlan',
  components: { AddModifyPage, DetailModifyPage },
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      isShowAddModify: false,
      isShowDetailModify: false,
      tableData: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'plan_Name_': '', // 巡检计划名称
        'plan_Start_Date_': '', // 巡检时间
        'plan_End_Date_': '',
        'plan_Type_': '' // 巡检类型
      },
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || [],
      rowInfo: {},
      componentName: 'table'
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        { operation: 'LIKE', property: 'plan_Name_' },
        { operation: 'EQUAL', property: 'planStartDate' },
        { operation: 'EQUAL', property: 'plan_End_Date_' },
        { operation: 'EQUAL', property: 'plan_Type_' }
      ]
      const { pageSize, page, ...item } = this.queryParams
      return {
        pageBean: { pageSize, page },
        querys: querys.flatMap(i => {
          /*
          * 取value值优先级：querys > queryParams
          * 方便后续有些参数默认值为一个固定的默认值，并且这个默认值不为空，也不会显示到页面上
          * */
          const value = i.value ?? item[i.property] ?? ''
          if (value === '') return []
          if (Array.isArray(value) && !value.length) return []
          return { group: 'main', relation: 'AND', ...i, value }
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,

    // 计划分发
    planDistribute(row) {
      this.$confirm('确定分发此巡检计划吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true
        planDistribute(row.id).then(res => {
          if (res.state) {
            this.$message.success('分发成功')
            this.queryParams.page = 1
            // this.loadData()
            row.planStatus = 1
          }
          this.loading = false
        })
      })

    },

    // 撤回分发
    handleRetract(row) {
      this.$confirm('确定撤回已分发的巡检计划吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true
        planRetract(row.id).then(res => {
          if (res.state) {
            this.$message.success('撤回成功')
            this.queryParams.page = 1
            // this.loadData()
            row.planStatus = 0
          }
          this.loading = false
        })
      })
    },

    // 获取list
    async loadData() {
      this.loading = true
      const { rows, total } = await tableData(this.computedQuery)
      this.tableData = rows
      this.queryParams.total = total
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.loadData()
    },

    // 删除
    handleDelete(row) {
      this.$confirm('确定删除选中的巡检计划吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(async () => {
        const loading = this.$loading({
          lock: true,
          text: `正在删除巡检计划中，请勿操作系统...`,
          spinner: 'el-icon-loading',
          background: 'rgba(255, 255, 255, 0.9)'
        })
        let ids = (row ? row.id : this.multipleSelection.join(',')) || ''
        if (!ids) return
        const { state, message } = await removePlanById(ids)
        if (state) {
          this.queryParams.page = 1
          await this.loadData()
          this.$message.success(message)
        } else {
          this.$message.error(message)
        }
        loading.close()
      }).catch(_ => _)
    },


    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = 1
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.page = 1
      this.queryParams.pageSize = pageSize
      this.loadData()
    },

    // 排序切换
    sortChange({ prop: property, order }) {
      let direction = ''
      switch (order) {
        case 'ascending':
          direction = 'ASC'
          break
        case 'descending':
          direction = 'DESC'
          break
      }
      this.sorter.forEach(i => {
        if (i.property !== property) return i.direction = ''
        i.direction = direction
      })
      this.loadData()
    },

    // 打开功能页面
    openPage(dialog, rowInfo = {}) {
      if (rowInfo.planStatus) {
        this.componentName = 'isShowDetailModify'
      } else {
        this.componentName = dialog
      }
      this.rowInfo = rowInfo // 保存点击行信息
    },

    // 关闭功能页面
    closePage(args) {
      switch (args) {
        case 'modify':
          this.queryParams.page = 1
          break
        case 'add':
          break
      }
      this.loadData()
      this.componentName = 'table'
      this.rowInfo = {}
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

::v-deep .el-link {
  span {
    font-size: 14PX;
  }
}
</style>
